api.reputation.v1.calculated.test_helpers.calculated_domain package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.calculated.test_helpers.calculated_domain package

## Submodules

## api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_domain module

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_domain.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/w+, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_domain.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/w+, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_domain.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/w+, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_domain.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/w+, respond with HTTP 401

## api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_i_p module

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_i_p.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/w+, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_i_p.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/w+, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_i_p.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/w+, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.calculate_reputation_for_i_p.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/w+, respond with HTTP 401

## api.reputation.v1.calculated.test_helpers.calculated_domain.find_address_reputation module

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_address_reputation.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/search, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_address_reputation.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/search, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_address_reputation.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/search, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_address_reputation.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip/search, respond with HTTP 401

## api.reputation.v1.calculated.test_helpers.calculated_domain.find_domain_reputation module

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_domain_reputation.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/search, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_domain_reputation.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/search, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_domain_reputation.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/search, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.find_domain_reputation.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain/search, respond with HTTP 401

## api.reputation.v1.calculated.test_helpers.calculated_domain.list_address_reputation module

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_address_reputation.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_address_reputation.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_address_reputation.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_address_reputation.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/ip, respond with HTTP 401

## api.reputation.v1.calculated.test_helpers.calculated_domain.list_domain_reputation module

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_domain_reputation.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain, respond with HTTP 403

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_domain_reputation.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain, respond with HTTP 404

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_domain_reputation.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain, respond with HTTP 200

`api.reputation.v1.calculated.test_helpers.calculated_domain.list_domain_reputation.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/calculated/domain, respond with HTTP 401

## Module contents